package me.mrletsplay.bmareas.command.area;

import java.util.Arrays;
import java.util.Collections;
import java.util.stream.Collectors;

import de.bluecolored.bluemap.api.markers.Marker;
import de.bluecolored.bluemap.api.markers.ShapeMarker;
import me.mrletsplay.bmareas.BMAreas;
import me.mrletsplay.mrcore.command.event.CommandInvokedEvent;
import me.mrletsplay.mrcore.fabric.command.FabricCommand;
import me.mrletsplay.mrcore.fabric.command.FabricCommandSender;
import net.minecraft.server.network.ServerPlayerEntity;
import net.minecraft.text.Text;

public class AreaRenameCommand extends FabricCommand {

	public AreaRenameCommand() {
		super("rename");
		setDescription("Rename an area");
		setUsage("/area rename <id> <new name>");

		setTabCompleter(event -> {
			FabricCommandSender sender = (FabricCommandSender) event.getSender();
			ServerPlayerEntity p = sender.asPlayer();
			if(p == null) return Collections.emptyList();

			if(event.getArgs().length == 0) {
				String prefix = p.getUuid().toString() + "_";
				return BMAreas.getAreaMarkerSet(p.getWorld()).getMarkers().entrySet().stream()
						.filter(en -> en.getKey().startsWith(prefix) && en.getValue() instanceof ShapeMarker)
						.map(en -> en.getKey().substring(prefix.length()))
						.collect(Collectors.toList());
			}else if(event.getArgs().length == 1) {
				return Arrays.asList("New name");
			}

			return Collections.emptyList();
		});
	}

	@Override
	public void action(CommandInvokedEvent event) {
		ServerPlayerEntity p = getSenderPlayer(event);
		if(p == null) {
			event.getSender().sendMessage("Player only!");
			return;
		}

		if(event.getArguments().length != 2) {
			sendCommandInfo(event.getSender());
			return;
		}

		String markerID = p.getUuid().toString() + "_" + event.getArguments()[0];
		Marker am = BMAreas.getAreaMarkerSet(p.getWorld()).get(markerID);
		if(am == null || !(am instanceof ShapeMarker)) {
			p.sendMessage(Text.literal("§cThat area doesn't exist"));
			return;
		}

		String newName = event.getArguments()[1];
		am.setLabel(newName);
		BMAreas.getAreaMarkerSet(p.getWorld()).put(markerID, am);
		BMAreas.saveMarkers();

		p.sendMessage(Text.literal("§aArea renamed successfully"));
	}

}
